==> savane-1.0.1.tar.gz: savane/frontend/php/admin/newgroup.php <==
<?php
// This file is part of the Savane project
// <http://gna.org/projects/savane/>
//
// $Id: newgroup.php,v 1.10 2004/01/31 00:56:17 yeupou Exp $
//
//
// 
// Copyright 1999-2000 (c) The SourceForge Crew
//
//
//  Copyright 2000-2001 (c) Free Software Foundation
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
//
//
//

require "../include/pre.php";    
session_require(array('group'=>'1','admin_flags'=>'A'));

// ###### function submit_valid()
// ###### checks for valid submit from form post

function submit_valid()	
{
	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':submit_valid()	';	global $HTTP_POST_VARS;

	if (!$HTTP_POST_VARS["Submit"]) {
		return 0;
	}
	
	if ($HTTP_POST_VARS['form_groupname']) {
		db_query("INSERT INTO groups (group_name,is_public) "
			. "values ('$HTTP_POST_VARS[form_groupname]',$HTTP_POST_VARS[form_public])");
		return 1;
	} else {
		return 0;
	}
}

// ###### first check for valid login, if so, congratulate

if (submit_valid()) {
	session_redirect("/admin/index.php");
} else { // not valid registration, or first time to page
	$HTML->header(array('title'=>"Admin: New Group"));

?>
<p><b>New Group Creation</b>
<?php
// This file is part of the Savane project
// <http://gna.org/projects/savane/>
//
// $Id: newgroup.php,v 1.10 2004/01/31 00:56:17 yeupou Exp $
// if ($submit_error) print "<p>$submit_error"; ?>
<form action="newgroup.php" method="post">
<p>Group Name:
<br><input type="text" name="form_groupname">
<p>Publicly browseable?:
<br><SELECT name="form_public">
<OPTION value="1">Yes
<OPTION selected value="0">No
</SELECT>
<p><input type="submit" name="Submit" value="Submit">
</form>

<?php
// This file is part of the Savane project
// <http://gna.org/projects/savane/>
//
// $Id: newgroup.php,v 1.10 2004/01/31 00:56:17 yeupou Exp $
//
}
$HTML->footer(array());

?>

==> savane-1.0.4.tar.gz: savane/frontend/php/admin/newgroup.php <==
<?php
// This file is part of the Savane project
// <http://gna.org/projects/savane/>
//
// $Id: newgroup.php,v 1.11 2004/09/22 08:11:50 yeupou Exp $
//
//
// 
// Copyright 1999-2000 (c) The SourceForge Crew
//
//
//  Copyright 2000-2001 (c) Free Software Foundation
// 
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
//
//
//

require "../include/pre.php";    
session_require(array('group'=>'1','admin_flags'=>'A'));

// ###### function submit_valid()
// ###### checks for valid submit from form post

function submit_valid()	
{
	$GLOBALS[sys_debug_where] = __FILE__.':'.__LINE__.':submit_valid()	';	global $HTTP_POST_VARS;

	if (!$HTTP_POST_VARS["Submit"]) {
		return 0;
	}
	
	if ($HTTP_POST_VARS['form_groupname']) {
		db_query("INSERT INTO groups (group_name,is_public) "
			. "values ('$HTTP_POST_VARS[form_groupname]',$HTTP_POST_VARS[form_public])");
		return 1;
	} else {
		return 0;
	}
}

// ###### first check for valid login, if so, congratulate

if (submit_valid()) {
	session_redirect("/admin/index.php");
} else { // not valid registration, or first time to page
	$HTML->header(array('title'=>"Admin: New Group"));

?>
<p><b>New Group Creation</b>
<?php
// This file is part of the Savane project
// <http://gna.org/projects/savane/>
//
// $Id: newgroup.php,v 1.11 2004/09/22 08:11:50 yeupou Exp $
// if ($submit_error) print "<p>$submit_error"; ?>
<form action="newgroup.php" method="post">
<p>Group Name:
<br /><input type="text" name="form_groupname">
<p>Publicly browseable?:
<br /><SELECT name="form_public">
<OPTION value="1">Yes
<OPTION selected value="0">No
</SELECT>
<p><input type="submit" name="Submit" value="Submit">
</form>

<?php
// This file is part of the Savane project
// <http://gna.org/projects/savane/>
//
// $Id: newgroup.php,v 1.11 2004/09/22 08:11:50 yeupou Exp $
//
}
$HTML->footer(array());

?>
